from .rival import rival

rivaldota2 = {
    "name": "SteelSeries Rival Dota 2 Edition",

    "vendor_id": 0x1038,
    "product_id": 0x1392,
    "interface_number": 0,

    "commands": rival["commands"]

}
